@@ -8,7 +8,13 @@ use warnings;
 use Plack::Util::Accessor qw[dir_index pretty];
 use URI::Escape;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
+
+sub css {
+  my $self = shift;
+
+  return $self->pretty ? $self->pretty_css : $self->standard_css;
+}
 
 sub standard_css {
   return <<CSS;
@@ -195,9 +201,7 @@ sub serve_path {
     my $f = $_;
     sprintf $self->file_html, map Plack::Util::encode_html($_), @$f;
   } @files;
-  my $page  = sprintf $self->dir_html, $path,
-                      ($self->pretty ? $self->pretty_css : $self->standard_css),
-                      $path, $files;
+  my $page  = sprintf $self->dir_html, $path, $self->css, $path, $files;
  
   return [ 200, ['Content-Type' => 'text/html; charset=utf-8'], [ $page ] ];
 }
@@ -232,7 +236,13 @@ Plack::App::DirectoryIndex - Serve static files from document root with an index
     root      => '/path/to/htdocs',
     dir_index => '',
   })->to_app;
-  
+
+  # Use the prettier CSS for directory listings
+  my $app = Plack::App::DirectoryIndex->new({
+    root   => '/path/to/htdocs',
+    pretty => 1,
+  })->to_app;
+
 
 =head1 DESCRIPTION
  
@@ -256,6 +266,12 @@ default to using C<index.html>. You can turn it off by setting this
 value to an empty string (but if you don't want a default index file,
 then you should probably use L<Plack::App::Directory> instead).
 
+=item pretty
+
+If set to a true value, the directory listing page will be rendered
+using an enhanced CSS stylesheet for a more attractive appearance.
+Defaults to false (i.e. the standard minimal CSS is used).
+
 =back
  
 =head1 AUTHOR
